from .base_model import *


class HltDoctorVisitTable(BaseModel):
    id = models.AutoField(db_column="DoctorVisitTableID", primary_key=True)
    doctor_time_table = models.ForeignKey("HltDoctorTimeTable", db_column="rf_DoctorTimeTableID", **FK_DEFAULT)
    tap = models.ForeignKey("HltTap", db_column="rf_TAPID", **FK_DEFAULT)
    comment = models.CharField(db_column="Comment", max_length=200)
    mkab = models.ForeignKey("HltMkab", db_column="rf_MKABID", **FK_DEFAULT)
    stub_print_counter = models.IntegerField(db_column="StubPrintCounter")
    visit_status = models.IntegerField(db_column="VisitStatus")
    flags = models.IntegerField(db_column="Flags")
    uguid = models.CharField(db_column="UGUID", max_length=36)
    user = models.ForeignKey("XUser", db_column="rf_UserID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    from_reg = models.BooleanField(db_column="fromReg")
    from_doc = models.BooleanField(db_column="fromDoc")
    from_infomat = models.BooleanField(db_column="fromInfomat")
    from_internet = models.BooleanField(db_column="fromInternet")
    from_tel = models.BooleanField(db_column="fromTel")
    norma_ue = models.IntegerField(db_column="NormaUE")
    stubn_um = models.CharField(db_column="StubNum", max_length=200)
    confirm_required = models.BooleanField(db_column="confirmRequired")
    edit_history = models.TextField(db_column="editHistory")
    er_id = models.CharField(db_column="ERID", max_length=8000)
    from_other_lpu = models.BooleanField(db_column="fromOtherLPU")
    reserved_to = models.DateTimeField(db_column="ReservedTo")
    direction_id = models.IntegerField(db_column="rf_DirectionID")
    fact_begin_time = models.DateTimeField(db_column="FactBeginTime")
    fact_end_time = models.DateTimeField(db_column="FactEndTime")
    date_time_call = models.DateTimeField(db_column="DateTimeCall")
    date_time_create = models.DateTimeField(db_column="DateTimeCreate")
    date_time_into_lpu = models.DateTimeField(db_column="DateTimeIntoLPU")
    num_ticket_queue = models.CharField(db_column="NumTicketQueue", max_length=200)
    date_visit_first_free = models.DateTimeField(db_column="DateVisitFirstFree")
    is_katl_visit = models.BooleanField(db_column="IsKatlVisit")
    is_confirmed = models.BooleanField(db_column="isConfirmed")
    doctor_visit_status_id = models.IntegerField(db_column="rf_DoctorVisitStatusID")
    prev_dvt_id = models.IntegerField(db_column="rf_PrevDvtID")
    confirmed_fio = models.CharField(db_column="ConfirmedFio", max_length=100)
    confirmed_date = models.DateTimeField(db_column="ConfirmedDate")

    class Meta:
        managed = False
        db_table = "hlt_DoctorVisitTable"



from .base_model import *


class HltBlankTemplate(BaseModel):
    id = models.AutoField(db_column="BlankTemplateID", primary_key=True)
    caption = models.CharField(db_column="Caption", max_length=250)
    code = models.CharField(db_column="Code", max_length=50)
    flags = models.IntegerField(db_column="Flags")
    guid = models.CharField(db_column="GUID", max_length=36)
    blank_template = models.ForeignKey("HltBlankTemplate", db_column="rf_BlankTemplateID", **FK_DEFAULT)
    template_edit = models.TextField(db_column="TemplateEdit")
    template_print = models.TextField(db_column="TemplatePrint")
    value = models.TextField(db_column="Value")
    validations = models.TextField(db_column="Validations")
    actual = models.BooleanField(db_column="Actual")
    comment = models.CharField(db_column="Comment", max_length=2000)
    source = models.CharField(db_column="Source", max_length=2000)
    author = models.CharField(db_column="Author", max_length=255)
    createdate = models.DateTimeField(db_column="CreateDate")
    rf_blank_template_type_id = models.IntegerField(db_column="rf_BlankTemplateTypeID")
    rf_context_id = models.IntegerField(db_column="rf_ContextID")
    version = models.CharField(db_column="Version", max_length=50)
    xml_data = models.TextField(db_column="XmlData")
    rf_med_record_type_guid = models.CharField(db_column="rf_MedRecordTypeGuid", max_length=36)

    class Meta:
        managed = False
        db_table = "hlt_BlankTemplate"



from .base_model import *


class OmsOkved(BaseModel):
    """
    Код экономического вида деятельности по ОКВЭД
    """

    id = models.AutoField(db_column="OKVEDID", primary_key=True)
    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
    name = models.CharField(db_column="NAME", max_length=100)
    code = models.CharField(db_column="OKVED_CODE", max_length=10)
    date_in = models.DateTimeField(db_column="DATEIN")
    date_out = models.DateTimeField(db_column="DATEOUT")
    date_edit = models.DateTimeField(db_column="DATEEDIT")

    class Meta:
        managed = False
        db_table = "oms_OKVED"



from .base_model import *


class OmsOrganisation(BaseModel):
    """
    Организации
    """

    id = models.AutoField(db_column="OrganisationID", primary_key=True)
    uuid = models.CharField(db_column="GUIDOrg", max_length=36, default=uuid4)
    fullname = models.CharField(db_column="FullName", max_length=200)
    shortname = models.CharField(db_column="ShortName", max_length=80)
    inn = models.CharField(db_column="INN", max_length=17)
    kpp = models.CharField(db_column="KPP", max_length=14)
    r_account = models.CharField(db_column="R_Account", max_length=25)
    bank = models.CharField(db_column="Bank", max_length=150)
    bik_bank = models.CharField(db_column="BIK_Bank", max_length=14)
    c_account = models.CharField(db_column="C_Account", max_length=25)
    ogrn = models.CharField(db_column="OGRN", max_length=15)
    c_okpo = models.CharField(db_column="C_OKPO", max_length=15)
    okato = models.ForeignKey("OmsOkato", models.DO_NOTHING, db_column="rf_OKATOID")
    okved = models.ForeignKey("OmsOkved", models.DO_NOTHING, db_column="rf_OKVEDID")
    address = models.CharField(db_column="Address", max_length=200)
    phone = models.CharField(db_column="Phone", max_length=40)
    fax = models.CharField(db_column="Fax", max_length=40)
    email = models.CharField(db_column="Email", max_length=40)
    fio_ruk = models.CharField(db_column="FIO_RUK", max_length=100)
    fio_bux = models.CharField(db_column="FIO_BUX", max_length=100)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    parent = models.ForeignKey("self", models.DO_NOTHING, db_column="rf_OrganisationParentID")
    code = models.CharField(db_column="Code", max_length=15)
    address_p = models.CharField(db_column="AdresP", max_length=250)
    docum = models.CharField(db_column="Docum", max_length=150)
    dop = models.CharField(db_column="Dop", max_length=250)
    fio_ruk_r = models.CharField(db_column="FIO_RUK_R", max_length=100)
    post = models.CharField(db_column="Post", max_length=150)
    rem = models.CharField(db_column="Rem", max_length=250)
    kla_address = models.ForeignKey("KlaAddress", models.DO_NOTHING, db_column="rf_AddressID")

    flags = models.IntegerField(db_column="FLAGS")

    class Meta:
        managed = False
        db_table = "oms_Organisation"



from .base_model import *


class HltRepresentativeMkab(BaseModel):
    """
    Представители пациента
    """

    id = models.AutoField(db_column="RepresentativeMKABID", primary_key=True)
    guid = models.CharField(db_column="GUID", max_length=36)
    address_live_str = models.CharField(db_column="AddressLive", max_length=200)
    address_reg_str = models.CharField(db_column="AddressReg", max_length=200)
    bd = models.DateTimeField(db_column="BD")
    birth_place = models.CharField(db_column="Birthplace", max_length=200)
    family = models.CharField(db_column="FAMILY", max_length=40)
    flags = models.IntegerField(db_column="Flags")
    is_main = models.BooleanField(db_column="isMain")
    is_no_ot = models.BooleanField(db_column="isNoOT")
    n_pol = models.CharField(db_column="N_POL", max_length=50)
    name = models.CharField(db_column="NAME", max_length=40)
    ot = models.CharField(db_column="OT", max_length=40)
    other_contact_inf = models.CharField(db_column="OtherContactInf", max_length=255)
    phone = models.CharField(db_column="Phone", max_length=25)
    post = models.CharField(db_column="Post", max_length=255)
    address_live = models.ForeignKey("KlaAddress", **FK_DEFAULT, db_column="rf_AddressLiveID")
    address_reg = models.ForeignKey("KlaAddress", **FK_DEFAULT, db_column="rf_AddressRegID")
    sex_id = models.IntegerField(db_column="rf_kl_SexID")
    tip_oms = models.ForeignKey("OmsKlTipOms", **FK_DEFAULT, db_column="rf_kl_TipOMSID")
    mkab = models.ForeignKey("HltMkab", **FK_DEFAULT, db_column="rf_MKABID")
    not_work_doc_care_id = models.IntegerField(db_column="rf_NotWorkDocCareID")
    patient_mkab = models.ForeignKey("HltMkab", **FK_DEFAULT, db_column="rf_PatientMKABID")
    smo = models.ForeignKey("OmsSmo", **FK_DEFAULT, db_column="rf_SMOID")
    s_pol = models.CharField(db_column="S_POL", max_length=50)
    work = models.CharField(db_column="Work", max_length=200)
    ss = models.CharField(db_column="SS", max_length=14)
    date_doc = models.DateTimeField(db_column="DateDoc")
    doc_issued_by = models.CharField(db_column="DocIssuedBy", max_length=255)
    n_doc = models.CharField(db_column="N_Doc", max_length=15)
    type_doc = models.IntegerField(db_column="rf_TypeDocID")
    s_doc = models.CharField(db_column="S_Doc", max_length=10)
    is_legal_org = models.BooleanField(db_column="isLegalOrg")
    address_org = models.ForeignKey("KlaAddress", **FK_DEFAULT, db_column="rf_AddressOrgID")
    name_org = models.CharField(db_column="NameOrg", max_length=255)
    ogrn_org = models.CharField(db_column="OgrnOrg", max_length=15)
    s_doc_representative = models.CharField(db_column="S_DocRepresentative", max_length=50)
    n_doc_representative = models.CharField(db_column="N_DocRepresentative", max_length=50)
    type_doc_representative_id = models.IntegerField(db_column="rf_TypeDocRepresentativeID")
    date_doc_representative = models.DateTimeField(db_column="DateDocRepresentative")
    doc_representative_by = models.CharField(db_column="DocRepresentativeBy", max_length=255)
    inn = models.CharField(db_column="INN", max_length=12)
    spec_event_cert = models.IntegerField(db_column="rf_SpecEventCertID")
    patient = models.IntegerField(db_column="rf_PatientID")
    oksm = models.IntegerField(db_column="rf_OKSMID")
    vedom = models.IntegerField(db_column="rf_kl_VedomID")

    class Meta:
        managed = False
        db_table = "hlt_RepresentativeMKAB"



from .base_model import *


class OmsPrvd(BaseModel):
    """
    В: Должности
    """

    id = models.AutoField(db_column="PRVDID", primary_key=True)
    name = models.CharField(db_column="NAME", max_length=100)
    c_prvd = models.CharField(db_column="C_PRVD", max_length=50)
    msg_text = models.CharField(db_column="MSG_TEXT", max_length=100)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    profit_type = models.ForeignKey("OmsKlProfitType", models.DO_NOTHING, db_column="rf_kl_ProfitTypeID")

    class Meta:
        managed = False
        db_table = "oms_PRVD"



from .base_model import *


class KlaAddress(BaseModel):
    id = models.AutoField(db_column="AddressID", primary_key=True)
    code = models.CharField(db_column="CODE", max_length=17)
    address_string = models.CharField(db_column="AddressString", max_length=500)
    appartment = models.CharField(db_column="Appartment", max_length=50)
    house = models.ForeignKey("KlaHouse", models.DO_NOTHING, db_column="rf_HouseID")
    area = models.CharField(db_column="Area", max_length=100)
    city = models.CharField(db_column="City", max_length=100)
    dop_data = models.CharField(db_column="DopData", max_length=500)
    region = models.CharField(db_column="Region", max_length=100)
    country = models.IntegerField(db_column="rf_CountryID")
    street = models.CharField(db_column="Street", max_length=100)
    locality = models.CharField(db_column="Locality", max_length=100)
    post_index = models.CharField(db_column="PostIndex", max_length=6)

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "kla_Address"



class Router:
    def db_for_read(self, model, **hints):
        if model._meta.app_label == "tmmis":
            return "tmmis"
        return None

    def db_for_write(self, model, **hints):
        if model._meta.app_label == "tmmis":
            return "tmmis"
        return None



from .base_model import *


class HltTap(BaseModel):
    """
    Талон амбулаторного пациента
    """

    id = models.AutoField(db_column="TAPID", primary_key=True)
    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
    mkab = models.ForeignKey("HltMkab", models.DO_NOTHING, db_column="rf_MKABID", related_name="taps")
    katl = models.IntegerField(db_column="rf_KATLID", default=0)
    mkb = models.ForeignKey("OmsMkb", db_column="rf_MKBID", **FK_DEFAULT)
    mkb2 = models.ForeignKey("OmsMkb", db_column="rf_MKB2ID", **FK_DEFAULT)
    reason_care = models.ForeignKey("HltReasonCare", db_column="rf_ReasonCareID", **FK_DEFAULT)
    care_person_sex = models.BooleanField(db_column="CarePersonSex", default=0)
    care_person_age = models.IntegerField(db_column="CarePersonAge", default=0)
    date_tap = models.DateTimeField(db_column="DateTAP", default=timezone.now)
    inv = models.IntegerField(db_column="rf_INVID", default=0)
    not_work_doc_status = models.IntegerField(db_column="rf_NotWorkDocStatusID", default=0)
    date_close = models.DateTimeField(db_column="DateClose", default=timezone.now)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    lpu_doctor_s = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctor_SID", **FK_DEFAULT)
    smo = models.ForeignKey("OmsSmo", db_column="rf_SMOID", **FK_DEFAULT)
    other_smo = models.ForeignKey("OmsSmo", db_column="rf_OtherSMOID", **FK_DEFAULT)
    s_pol = models.CharField(db_column="S_POL", max_length=50, default="")
    n_pol = models.CharField(db_column="N_POL", max_length=50, default="")
    is_closed = models.BooleanField(db_column="IsClosed", default=0)
    is_worker = models.BooleanField(db_column="isWorker", default=0)
    spec_event_cert_id = models.IntegerField(db_column="rf_SpecEventCertID", default=0)
    care_begin = models.DateTimeField(db_column="CareBegin", default=timezone.now)
    care_end = models.DateTimeField(db_column="CareEnd", default=timezone.now)
    family = models.CharField(db_column="FAMILY", max_length=40, default="")
    mkab_sheet_final_ds = models.IntegerField(db_column="rf_MKABSheetFinalDSID", default=0)
    direction_id = models.IntegerField(db_column="rf_DirectionID", default=0)
    outcome_visit_id = models.IntegerField(db_column="rf_OutcomeVisitID", default=0)
    description = models.CharField(db_column="Description", max_length=1000, default="")
    profit_type = models.ForeignKey("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
    disp_reg_state_id = models.IntegerField(db_column="rf_kl_DispRegStateID", default=0)
    disp_reg_state2_id = models.IntegerField(db_column="rf_kl_DispRegState2ID", default=0)
    disease_type = models.ForeignKey("OmsKlDiseaseType", db_column="rf_kl_DiseaseTypeID", **FK_DEFAULT)
    disease_type2 = models.ForeignKey("OmsKlDiseaseType", db_column="rf_kl_DiseaseType2ID", **FK_DEFAULT)
    trauma_type_id = models.IntegerField(db_column="rf_kl_TraumaTypeID", default=0)
    sick_list_reason = models.IntegerField(db_column="rf_kl_SickListReasonID", default=0)
    visit_result = models.ForeignKey("OmsKlVisitResult", db_column="rf_kl_VisitResultID", **FK_DEFAULT)
    registration_end_reason_id = models.IntegerField(db_column="rf_kl_RegistrationEndReasonID", default=0)
    registration_end_reason2_id = models.IntegerField(db_column="rf_kl_RegistrationEndReason2ID", default=0)
    health_group = models.ForeignKey("OmsKlHealthGroup", db_column="rf_kl_HealthGroupID", **FK_DEFAULT)
    visit_place = models.ForeignKey("OmsKlVisitPlace", db_column="rf_kl_VisitPlaceID", **FK_DEFAULT)
    reason_type = models.ForeignKey("OmsKlReasonType", db_column="rf_kl_ReasonTypeID", **FK_DEFAULT)
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    soc_status = models.ForeignKey("OmsKlSocStatus", db_column="rf_kl_SocStatusID", **FK_DEFAULT)
    create_username = models.CharField(db_column="CreateUserName", max_length=255, default="не определено")
    edit_username = models.CharField(db_column="EditUserName", max_length=255, default="не определено")
    flag_bill = models.BooleanField(db_column="FlagBill", default=0)
    flag_statist = models.BooleanField(db_column="FlagStatist", default=0)
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
    stat_cure_result = models.ForeignKey("OmsKlStatCureResult", db_column="rf_kl_StatCureResultID", **FK_DEFAULT)
    polis_mkab_id = models.IntegerField(db_column="rf_PolisMKABID", default=0)
    type_tap_id = models.IntegerField(db_column="rf_TypeTAPID", default=0)
    registr_patient_id = models.IntegerField(db_column="rf_RegistrPatientID", default=0)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    # mkp_card = models.UUIDField(db_column="rf_mkp_CardGUID", **NULL)
    date_create_tap = models.DateTimeField(db_column="DateCreateTAP", default=timezone.now)
    num_in_other_system = models.CharField(db_column="NumInOtherSystem", max_length=50, default="")
    is_dvn_closed = models.BooleanField(db_column="isDVNClosed", default=0)
    med_care_type = models.ForeignKey("OmsKlMedCareType", db_column="rf_kl_MedCareTypeID", **FK_DEFAULT)
    disability_status = models.IntegerField(db_column="DisabilityStatus", default=0)
    reason_inv_id = models.IntegerField(db_column="rf_kl_ReasonInvID", default=0)
    mkb_external = models.ForeignKey("OmsMkb", db_column="rf_MKBExternalID", **FK_DEFAULT)
    sanitation_id = models.IntegerField(db_column="rf_kl_SanitationID", default=0)
    patient_status_id = models.IntegerField(db_column="rf_kl_PatientStatusID", default=0)
    onco_sign_id = models.IntegerField(db_column="rf_onco_SignID", default=0)
    dd_service = models.ForeignKey("OmsKlDDService", db_column="rf_kl_DDServiceID", **FK_DEFAULT)
    tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
    num = models.IntegerField(db_column="Num", default=0)

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_TAP"



from .base_model import *


class HltTypeCallDoctor(BaseModel):
    id = models.AutoField(db_column="TypeCallDoctorID", primary_key=True)
    code = models.CharField(db_column="CODE", max_length=1)
    name = models.CharField(db_column="NAME", max_length=20)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    enum_name = models.CharField(db_column="EnumName", max_length=50)
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_TypeCallDoctor"



from .base_model import *


class OmsKlProfitType(BaseModel):
    """
    Классификатор типов пациентов
    """

    id = models.AutoField(db_column="kl_ProfitTypeID", primary_key=True)
    code = models.CharField(db_column="CODE", max_length=50)
    name = models.CharField(db_column="NAME", max_length=255)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")

    class Meta:
        managed = False
        db_table = "oms_kl_ProfitType"



from .base_model import *


class HltLpuDoctor(BaseModel):
    """
    Медицинский персонал
    """

    id = models.AutoField(db_column="LPUDoctorID", primary_key=True)
    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
    pcod = models.CharField(db_column="PCOD", max_length=20)
    ot_v = models.CharField(db_column="OT_V", max_length=20)
    im_v = models.CharField(db_column="IM_V", max_length=20)
    d_ser = models.DateTimeField(db_column="D_SER")
    prvs = models.ForeignKey("OmsPrvs", db_column="rf_PRVSID", **FK_DEFAULT)
    fam_v = models.CharField(db_column="FAM_V", max_length=30)
    kv_kat = models.IntegerField(db_column="rf_KV_KATID")
    msg_text = models.CharField(db_column="MSG_Text", max_length=100)
    lpu = models.IntegerField(db_column="rf_LPUID")
    is_doctor = models.BooleanField(db_column="isDoctor")
    healing_room = models.IntegerField(db_column="rf_HealingRoomID")
    in_time = models.SmallIntegerField(db_column="inTime")
    dr = models.DateTimeField(db_column="DR")
    is_special = models.BooleanField(db_column="IsSpecial")
    prvd = models.IntegerField(db_column="rf_PRVDID")
    ss = models.CharField(db_column="SS", max_length=14)
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    de_ser = models.DateTimeField(db_column="DE_SER")
    phone = models.CharField(db_column="Phone", max_length=25)

    class Meta:
        managed = False
        db_table = "hlt_LPUDoctor"



from .base_model import *


class OmsKlTipOms(BaseModel):
    """
    Классификатор типов документов, подтверждающих факт страхования по ОМС (F008)
    """

    id = models.AutoField(db_column="kl_TipOMSID", primary_key=True)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    doc_name = models.CharField(db_column="DOCNAME", max_length=254)
    id_doc = models.IntegerField(db_column="IDDOC")

    class Meta:
        managed = False
        db_table = "oms_kl_TipOMS"



from .base_model import *


class Gender(models.IntegerChoices):
    FEMALE = (0,)
    MALE = 1


class HltMkab(BaseModel):
    """
    Медицинская карта амбулаторного больного
    """

    id = models.AutoField(db_column="MKABID", primary_key=True)
    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
    family = models.CharField(db_column="FAMILY", max_length=40)
    name = models.CharField(db_column="NAME", max_length=40)
    ot = models.CharField(db_column="OT", max_length=40)
    ss = models.CharField(db_column="SS", max_length=14)
    d_type = models.CharField("Признак Особый случай", db_column="D_TYPE", max_length=3)
    num = models.CharField(db_column="NUM", max_length=40)
    w = models.IntegerField(db_column="W", choices=Gender.choices)
    date_bd = models.DateTimeField(db_column="DATE_BD")
    address = models.CharField(db_column="ADRES", max_length=200)
    inv_id = models.IntegerField(db_column="rf_INVID")
    smo = models.ForeignKey("OmsSmo", db_column="rf_SMOID", **FK_DEFAULT)
    other_smo = models.ForeignKey("OmsSmo", db_column="rf_OtherSMOID", **FK_DEFAULT)
    phone_work = models.CharField(db_column="PhoneWork", max_length=20)
    phone_home = models.CharField(db_column="PhoneHome", max_length=20)
    work = models.CharField(db_column="Work", max_length=200)
    profession = models.CharField(db_column="Profession", max_length=50)
    post = models.CharField(db_column="Post", max_length=50)
    dependent = models.BooleanField(db_column="Dependent")
    lpu = models.ForeignKey("OmsLpu", models.DO_NOTHING, db_column="rf_LPUID")
    # rf_group_of_blood = models.ForeignKey('HltGroupOfBloodRh', models.DO_NOTHING, db_column='rf_GroupOfBloodID')
    kindcod = models.BooleanField(db_column="KindCod")
    rh = models.BooleanField(db_column="RH")
    cod_person = models.CharField(db_column="COD_Person", max_length=20)
    military_cod = models.CharField(db_column="MilitaryCOD", max_length=3)
    uchastok = models.ForeignKey("HltUchastok", models.DO_NOTHING, db_column="rf_UchastokID")
    citizen_id = models.IntegerField(db_column="rf_CitizenID")
    type_doc = models.ForeignKey("OmsTypedoc", models.DO_NOTHING, db_column="rf_TYPEDOCID")
    s_doc = models.CharField(db_column="S_DOC", max_length=10)
    n_doc = models.CharField(db_column="N_DOC", max_length=15)
    tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
    s_pol = models.CharField(db_column="S_POL", max_length=50)
    n_pol = models.CharField(db_column="N_POL", max_length=50)
    is_worker = models.BooleanField(db_column="IsWorker")
    mkab_location_id = models.IntegerField(db_column="rf_MKABLocationID")
    spec_event_cert_id = models.IntegerField(db_column="rf_SpecEventCertID")
    address_fact = models.CharField(db_column="AdresFact", max_length=200)
    date_pol_begin = models.DateTimeField(db_column="DatePolBegin")
    date_pol_end = models.DateTimeField(db_column="DatePolEnd")
    enterprise_id = models.IntegerField(db_column="rf_EnterpriseID")
    black_label = models.IntegerField(db_column="BlackLabel")
    okato = models.ForeignKey("OmsOkato", models.DO_NOTHING, db_column="rf_OKATOID")
    is_closed = models.IntegerField(db_column="isClosed")
    reason_close_mkab_id = models.IntegerField(db_column="rf_ReasonCloseMKABID")
    date_close = models.DateTimeField(db_column="DateClose")
    privilege_category_id = models.IntegerField(db_column="rf_kl_PrivilegeCategoryID")
    oms_okved = models.ForeignKey("OmsOkved", models.DO_NOTHING, db_column="rf_omsOKVEDID")
    soc_status = models.ForeignKey("OmsKlSocStatus", db_column="rf_kl_SocStatusID", **FK_DEFAULT)
    sex_id = models.IntegerField(db_column="rf_kl_SexID")
    health_group = models.ForeignKey("OmsKlHealthGroup", db_column="rf_kl_HealthGroupID", **FK_DEFAULT)
    address_live = models.ForeignKey("KlaAddress", db_column="rf_AddressLiveID", **FK_DEFAULT)
    address_reg = models.ForeignKey("KlaAddress", db_column="rf_AddressRegID", **FK_DEFAULT)
    address_work = models.ForeignKey("KlaAddress", db_column="rf_AddressWorkID", **FK_DEFAULT)
    confirm_agree = models.BooleanField(db_column="ConfirmAgree")
    confirm_date = models.DateTimeField(db_column="ConfirmDate")
    confirm_user_fio = models.CharField(db_column="ConfirmUserFIO", max_length=50)
    contact_confirm = models.BooleanField(db_column="contactConfirm")
    contact_email = models.CharField(db_column="contactEmail", max_length=100)
    contact_mphone = models.CharField(db_column="contactMPhone", max_length=25)
    create_username = models.CharField(db_column="CreateUserName", max_length=255)
    edit_username = models.CharField(db_column="EditUserName", max_length=255)
    confirm_user = models.ForeignKey("XUser", db_column="rf_ConfirmUserID", **FK_DEFAULT)
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
    hash0 = models.CharField(db_column="Hash0", max_length=65)
    hash1 = models.CharField(db_column="Hash1", max_length=65)
    hash2 = models.CharField(db_column="Hash2", max_length=65)
    hash3 = models.CharField(db_column="Hash3", max_length=65)
    hash4 = models.CharField(db_column="Hash4", max_length=65)
    is_encrypted = models.BooleanField(db_column="isEncrypted")
    main_contact = models.IntegerField(db_column="mainContact")
    message_flag = models.IntegerField(db_column="MessageFLAG")
    ridn = models.CharField(db_column="RIDN", max_length=10)
    mkab_info = models.TextField(db_column="MKABInfo")
    birth_place = models.CharField(db_column="Birthplace", max_length=200)
    date_doc = models.DateTimeField(db_column="DateDoc")
    is_ls_home = models.BooleanField(db_column="isLSHome")
    main_mkab = models.ForeignKey("self", models.DO_NOTHING, db_column="MainMKABGuid", to_field="uuid")
    date_mkab = models.DateTimeField(db_column="DateMKAB")
    doc_issued_by = models.CharField(db_column="DocIssuedBy", max_length=255)
    education_type_id = models.IntegerField(db_column="rf_kl_EducationTypeID")
    material_status_id = models.IntegerField(db_column="rf_kl_MaterialStatusID")
    is_auto = models.BooleanField(db_column="isAuto")
    black_label_comment = models.CharField(db_column="BlackLabelComment", max_length=255)
    is_exist_ipra = models.BooleanField(db_column="isExistIPRA")
    oksm_id = models.IntegerField(db_column="rf_OKSMID")
    identification_date = models.DateTimeField(db_column="IdentificationDate")
    identification_status_id = models.IntegerField(db_column="rf_IdentificationStatusID")
    is_no_email = models.BooleanField(db_column="IsNoEmail")
    is_no_phone = models.BooleanField(db_column="IsNoPhone")
    med_intervention = models.SmallIntegerField(db_column="MedIntervention")
    rhesus = models.SmallIntegerField(db_column="Rhesus")
    qualification = models.CharField(db_column="Qualification", max_length=255)
    group = models.CharField(db_column="Group", max_length=255)
    military_duty_id = models.IntegerField(db_column="rf_MilitaryDutyID")
    inn = models.CharField(db_column="INN", max_length=12)
    milk_food_type_id = models.IntegerField(db_column="rf_atc_MilkFoodTypeID")
    milk_food_payment_id = models.IntegerField(db_column="rf_atc_MilkFoodPaymentID")
    food_payment_date = models.DateTimeField(db_column="FoodPaymentDate")

    flags = models.IntegerField(db_column="FLAGS")

    class Meta:
        managed = False
        db_table = "hlt_MKAB"



from .base_model import *


class AtfFileInfo(BaseModel):
    """
    Информация о прикрепленном документе
    """

    id = models.AutoField(db_column="FileInfoID", primary_key=True)
    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)

    date_doc = models.DateTimeField("Дата документа", db_column="DateDoc", default=timezone.now)
    desc_guid = models.CharField("Уникальный идентификатор источника", db_column="DescGuid", max_length=36)
    description = models.TextField("Описание", db_column="Description", default="")
    doctor_name = models.CharField("ФИО врача", db_column="DoctorName", max_length=255, default="")
    lpu_name = models.CharField("Наименование ЛПУ", db_column="LPUName", max_length=255, default="")
    desc_type = models.CharField("Тип документа источника", db_column="rf_DescTypeGuid", max_length=36)
    doctor_guid = models.CharField(
        "Врач",
        db_column="rf_DoctorGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    doctor_type = models.CharField(
        "Тип элемента БД, характеризующий доктора",
        db_column="rf_DoctorTypeGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    file_type = models.ForeignKey("AtfFileType", db_column="rf_FileTypeID", **FK_DEFAULT)
    lpu = models.ForeignKey("OmsLpu", to_field="uuid", db_column="rf_LPUGuid", max_length=36, **FK_DEFAULT)
    lpu_type = models.CharField(db_column="rf_LPUTypeGuid", max_length=36)

    flags = models.IntegerField(db_column="Flags", default=0)

    class Meta:
        managed = False
        db_table = "atf_FileInfo"



from .base_model import *


class OmsLpu(BaseModel):
    """
    Лечебно-профилактические учреждения (ЛПУ)
    """

    id = models.AutoField(db_column="LPUID", primary_key=True)
    uuid = models.CharField(db_column="GUIDLPU", max_length=36, unique=True, default=uuid4)
    okato = models.ForeignKey("OmsOkato", models.DO_NOTHING, db_column="rf_OKATOID")
    c_ogrn = models.CharField(db_column="C_OGRN", max_length=15)
    m_names = models.CharField(db_column="M_NAMES", max_length=200)
    m_namef = models.CharField(db_column="M_NAMEF", max_length=1000)
    c_inn = models.CharField(db_column="C_INN", max_length=15)
    c_kpp = models.CharField(db_column="C_KPP", max_length=15)
    c_okved = models.CharField(db_column="C_OKVED", max_length=50)
    c_okogu = models.CharField(db_column="C_OKOGU", max_length=10)
    fam_gv = models.CharField(db_column="FAM_GV", max_length=40)
    im_gv = models.CharField(db_column="IM_GV", max_length=40)
    ot_gv = models.CharField(db_column="OT_GV", max_length=40)
    fam_bux = models.CharField(db_column="FAM_BUX", max_length=40)
    im_bux = models.CharField(db_column="IM_BUX", max_length=40)
    ot_bux = models.CharField(db_column="OT_BUX", max_length=40)
    tel = models.CharField(db_column="TEL", max_length=40)
    fax = models.CharField(db_column="FAX", max_length=40)
    e_mail = models.CharField(db_column="E_MAIL", max_length=50)
    date_b = models.DateTimeField(db_column="DATE_B")
    date_e = models.DateTimeField(db_column="DATE_E")
    c_n_fil = models.SmallIntegerField(db_column="C_N_FIL")
    address = models.CharField(db_column="ADRES", max_length=200)
    mcod = models.CharField(db_column="MCOD", unique=True, max_length=10)
    klpu = models.CharField(db_column="KLPU", max_length=1)
    post_idp = models.DecimalField(db_column="POST_IDP", max_digits=6, decimal_places=0)
    okpo = models.CharField(db_column="OKPO", max_length=8)
    organisation = models.ForeignKey("OmsOrganisation", models.DO_NOTHING, db_column="rf_OrganisationID")
    # tariff_type = models.ForeignKey('OmsKlTariffType', models.DO_NOTHING, db_column='rf_kl_TariffTypeID')
    # category = models.ForeignKey('OmsKlCategory', models.DO_NOTHING, db_column='rf_kl_CategoryID')
    ndog = models.CharField(db_column="NDOG", max_length=50)
    ddogfss = models.DateTimeField(db_column="DDOGFSS")
    lic = models.CharField(db_column="Lic", max_length=50)
    code_mo = models.IntegerField(db_column="Code_MO")
    fcod = models.CharField(db_column="FCOD", max_length=6)
    # type_lpu = models.ForeignKey('OmsKlTypeLpu', models.DO_NOTHING, db_column='rf_kl_Type_LPUID')
    main_lpu = models.ForeignKey("self", models.DO_NOTHING, db_column="rf_MainLPUID")
    stlpu = models.CharField(db_column="StLPU", max_length=1)
    # agegroup = models.ForeignKey('OmsKlAgegroup', models.DO_NOTHING, db_column='rf_kl_AgeGroupID')
    # tariff_target = models.ForeignKey('OmsTariffTarget', models.DO_NOTHING, db_column='rf_TariffTargetID')
    in_demand = models.BooleanField(db_column="InDemand")
    date_n_beg = models.DateTimeField(db_column="DateN_Beg")
    date_n_end = models.DateTimeField(db_column="DateN_End")
    code_kladr = models.CharField(db_column="CodeKladr", max_length=10)
    code_ruk = models.CharField(db_column="CodeRuk", max_length=10)
    dop_fk = models.CharField(db_column="DopFK", max_length=10)
    host = models.IntegerField(db_column="HostID")
    kfsr = models.CharField(db_column="KFSR", max_length=10)
    kosgu = models.CharField(db_column="KOSGU", max_length=10)
    kvr = models.CharField(db_column="KVR", max_length=10)
    kvsr = models.CharField(db_column="KVSR", max_length=10)
    kla_address = models.ForeignKey("KlaAddress", models.DO_NOTHING, db_column="rf_AddressID")
    prvd = models.ForeignKey("OmsPrvd", models.DO_NOTHING, db_column="rf_PRVDID")
    mdlpc_ode = models.CharField(db_column="MdlpCode", max_length=150)
    code_egisz = models.CharField(db_column="CodeEgisz", max_length=150)
    # med_care_type = models.ForeignKey('OmsKlMedCareType', models.DO_NOTHING, db_column='rf_kl_MedCareTypeID')

    flags = models.IntegerField(db_column="FLAGS")

    class Meta:
        managed = False
        db_table = "oms_LPU"



from .atf_file_attachment import AtfFileAttachment
from .atf_file_info import AtfFileInfo
from .atf_file_type import AtfFileType
from .hlt_blank_template import HltBlankTemplate
from .hlt_call_doctor import HltCallDoctor
from .hlt_call_doctor_status import HltCallDoctorStatus
from .hlt_doc_prvd import HltDocPrvd
from .hlt_doctor_time_table import HltDoctorTimeTable
from .hlt_doctor_visit_table import HltDoctorVisitTable
from .hlt_lpu_doctor import HltLpuDoctor
from .hlt_med_record import HltMedRecord
from .hlt_mkab import HltMkab, Gender
from .hlt_reason_care import HltReasonCare
from .hlt_representative_mkab import HltRepresentativeMkab
from .hlt_smtap import HltSmTap
from .hlt_tap import HltTap
from .hlt_type_call_doctor import HltTypeCallDoctor
from .hlt_uchastok import HltUchastok
from .hlt_visit_history import HltVisitHistory
from .kla_address import KlaAddress
from .kla_house import KlaHouse
from .kla_kladr import KlaKladr
from .kla_street import KlaStreet
from .oms_department import OmsDepartment
from .oms_kl_age_group import OmsKlAgeGroup
from .oms_kl_dd_service import OmsKlDDService
from .oms_kl_department_profile import OmsKlDepartmentProfile
from .oms_kl_department_type import OmsKlDepartmentType
from .oms_kl_disease_type import OmsKlDiseaseType
from .oms_kl_health_group import OmsKlHealthGroup
from .oms_kl_med_care_type import OmsKlMedCareType
from .oms_kl_profit_type import OmsKlProfitType
from .oms_kl_reason_type import OmsKlReasonType
from .oms_kl_soc_status import OmsKlSocStatus
from .oms_kl_stat_cure_result import OmsKlStatCureResult
from .oms_kl_tip_oms import OmsKlTipOms
from .oms_kl_visit_place import OmsKlVisitPlace
from .oms_kl_visit_result import OmsKlVisitResult
from .oms_lpu import OmsLpu
from .oms_mkb import OmsMkb
from .oms_okato import OmsOkato
from .oms_okved import OmsOkved
from .oms_organisation import OmsOrganisation
from .oms_prvd import OmsPrvd
from .oms_prvs import OmsPrvs
from .oms_service_medical import OmsServiceMedical
from .oms_smo import OmsSmo
from .oms_type_doc import OmsTypedoc
from .x_user import XUser



# noinspection PyUnresolvedReferences
from uuid import uuid4, UUID

from django.db import models
# noinspection PyUnresolvedReferences
from django.utils import timezone

FK_DEFAULT = {"on_delete": models.DO_NOTHING, "related_name": "+", "default": 0}
NULL = {"blank": True, "null": True}


class BaseModel(models.Model):
    x_edition = models.IntegerField(db_column="x_Edition", default=1)
    x_status = models.SmallIntegerField(db_column="x_Status", default=1)

    class Meta:
        abstract = True



from .base_model import *


class HltReasonCare(BaseModel):
    """
    Причина выдачи док-та о врем. нетрудоспособности
    """

    id = models.AutoField(db_column="ReasonCareID", primary_key=True)
    cod = models.CharField(db_column="COD", max_length=6)
    name = models.CharField(db_column="NAME", max_length=50)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_ReasonCare"



from .base_model import *


class HltMedRecord(BaseModel):
    id = models.AutoField(db_column="MedRecordID", primary_key=True)
    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
    confidentiality_code = models.CharField(db_column="ConfidentialityCode", max_length=50)
    crc = models.TextField(db_column="CRC")
    data = models.TextField(db_column="Data")
    date = models.DateTimeField(db_column="Date")
    blank_template = models.ForeignKey("HltBlankTemplate", db_column="rf_BlankTemplateID", **FK_DEFAULT)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    visit_history = models.ForeignKey(
        "HltVisitHistory",
        models.DO_NOTHING,
        db_column="rf_VisitHistoryID",
        related_name="med_records",
    )
    sign = models.TextField(db_column="Sign")
    event_data_time = models.DateTimeField(db_column="EventDataTime")
    person = models.ForeignKey(
        "HltMkab",
        models.DO_NOTHING,
        db_column="PersonGUID",
        to_field="uuid",
        related_name="med_records",
    )
    doc = models.CharField(db_column="rf_DOCGUID", max_length=36)
    doc_type_def = models.CharField(db_column="rf_DocTypeDefGUID", max_length=36)
    view_data = models.TextField(db_column="ViewData")
    create_username = models.CharField(db_column="CreateUserName", max_length=255)
    edit_username = models.CharField(db_column="EditUserName", max_length=255)
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
    desc = models.CharField(db_column="DescGuid", max_length=36)
    create_date = models.DateTimeField(db_column="CreateDate")
    description = models.TextField(db_column="Description")
    doc_prvd = models.CharField(db_column="rf_DocPrvdGuid", max_length=36)
    mkab = models.ForeignKey("HltMkab", db_column="rf_MKABGuid", to_field="uuid", **FK_DEFAULT)
    is_upload = models.BooleanField(db_column="isUpload")
    is_del = models.BooleanField(db_column="IsDel")

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_MedRecord"



from .base_model import *


class HltCallDoctor(BaseModel):
    id = models.AutoField(db_column="CallDoctorID", primary_key=True)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    mkab = models.ForeignKey("HltMkab", db_column="rf_MKABID", **FK_DEFAULT)
    address = models.CharField(db_column="Address", max_length=200)
    complaint = models.CharField(db_column="Complaint", max_length=500)
    date_call = models.DateTimeField(db_column="DateCall")
    status = models.ForeignKey("HltCallDoctorStatus", db_column="rf_CallDoctorStatusID", **FK_DEFAULT)
    is_finalize = models.BooleanField(db_column="isFinalize")
    date_finalize = models.DateTimeField(db_column="DateFinalize")
    tap = models.ForeignKey("HltTap", **FK_DEFAULT, db_column="rf_TAPID")
    code_domophon = models.CharField(db_column="CodeDomophon", max_length=20)
    phone = models.CharField(db_column="Phone", max_length=25)
    finalize_lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="Rf_FinalizeLPUDoctorID", **FK_DEFAULT)
    description = models.CharField(db_column="Description", max_length=100)
    type_call_doctor = models.ForeignKey("HltTypeCallDoctor", db_column="rf_TypeCallDoctorID", **FK_DEFAULT)
    entrance = models.IntegerField(db_column="Entrance")
    floor = models.IntegerField(db_column="Floor")
    rf_address = models.ForeignKey("KlaAddress", db_column="rf_AddressID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    finalize_doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_FinalizeDocPRVDID", **FK_DEFAULT)
    date_visit = models.DateTimeField(db_column="DateVisit")
    guid = models.CharField(db_column="GUID", max_length=36)
    lpu = models.ForeignKey("OmsLpu", db_column="rf_LPUID", **FK_DEFAULT)
    source_dvt = models.IntegerField(db_column="SourceDvt")
    birth_date = models.DateTimeField(db_column="BirthDate")
    date_status = models.DateTimeField(db_column="DateStatus")
    family = models.CharField(db_column="Family", max_length=40)
    name = models.CharField(db_column="Name", max_length=40)
    number_pol = models.CharField(db_column="NumberPol", max_length=50)
    ot = models.CharField(db_column="Ot", max_length=40)
    rf_kl_sexid = models.IntegerField(db_column="rf_kl_SexID")
    mkb = models.ForeignKey("OmsMkb", db_column="rf_MKBID", **FK_DEFAULT)
    series_pol = models.CharField(db_column="SeriesPol", max_length=50)
    cause_cancel = models.TextField(db_column="CauseCancel")
    source_smp = models.TextField(db_column="SourceSmp")
    call_family = models.CharField(db_column="Call_Family", max_length=40)
    call_name = models.CharField(db_column="Call_Name", max_length=40)
    call_patronymic = models.CharField(db_column="Call_Patronymic", max_length=40)
    rf_call_person_type_id = models.IntegerField(db_column="rf_CallPersonTypeID")
    age = models.IntegerField(db_column="Age")
    age_title = models.IntegerField(db_column="AgeTitle")
    date_active = models.DateTimeField(db_column="DateActive")
    date_resolved = models.DateTimeField(db_column="DateResolved")
    is_child = models.BooleanField(db_column="isChild")
    is_notification = models.BooleanField(db_column="IsNotification")
    uchastok = models.ForeignKey("HltUchastok", db_column="rf_UchastokID", **FK_DEFAULT)
    age_group = models.ForeignKey("OmsKlAgeGroup", db_column="rf_kl_AgeGroupID", **FK_DEFAULT)
    rf_call_cancel_reason_id = models.IntegerField(db_column="rf_CallCancelReasonID")
    is_sent_to_doctor = models.BooleanField(db_column="IsSentToDoctor")

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_CallDoctor"



from .base_model import *


class HltDocPrvd(BaseModel):
    id = models.AutoField(db_column="DocPRVDID", primary_key=True)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    d_prik = models.DateTimeField(db_column="D_PRIK")
    s_st = models.DecimalField(db_column="S_ST", max_digits=5, decimal_places=3)
    d_end = models.DateTimeField(db_column="D_END")
    prvs = models.ForeignKey("OmsPrvs", db_column="rf_PRVSID", **FK_DEFAULT)
    healing_room_id = models.IntegerField(db_column="rf_HealingRoomID")
    kat_id = models.IntegerField(db_column="rf_KV_KATID")
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    main_work_place = models.BooleanField(db_column="MainWorkPlace")
    guid = models.CharField(db_column="GUID", max_length=36)
    in_time = models.IntegerField(db_column="InTime")
    prvd = models.ForeignKey("OmsPrvd", db_column="rf_PRVDID", **FK_DEFAULT)
    name = models.CharField(db_column="Name", max_length=100)
    rf_equipment_id = models.IntegerField(db_column="rf_EquipmentID")
    rf_resource_type_id = models.IntegerField(db_column="rf_ResourceTypeID")
    shown_in_schedule = models.BooleanField(db_column="ShownInSchedule")
    er_id = models.CharField(db_column="ERID", max_length=8000)
    er_name = models.CharField(db_column="ERName", max_length=8000)
    nom_service_code = models.CharField(db_column="NomServiceCode", max_length=50)
    is_special = models.BooleanField(db_column="isSpecial")
    department_type_id = models.IntegerField(db_column="rf_kl_DepartmentTypeID")
    is_dismissal = models.BooleanField(db_column="isDismissal")
    interval = models.IntegerField(db_column="Interval")
    is_use_interval = models.BooleanField(db_column="isUseInterval")
    pcod = models.CharField(db_column="PCOD", max_length=20)
    is_conclusion = models.BooleanField(db_column="isConclusion")
    assignment_doctor_id = models.IntegerField(db_column="rf_AssignmentDoctorID")

    class Meta:
        managed = False
        db_table = "hlt_DocPRVD"
